function fig = EDGEDEMOINT()
%EDGEDEMOINT Edge detection demo.
%
%   This interface demonstrates the different edge detection methods.
%   Use the image-Load menu on the top to select the input image.
%   Use the Method popup menu to select an edge detection method.  
%   You can control the parameters for the different methods by
%   setting the values in the middle frame at the bottom of the figure.
%   (The set of parameters differs depending on the method you choose.)
%   Press the "Apply" button to calculate the edge map 
%   using the specified method and parameters.
%
%   For the Sobel, Prewitt, and Roberts methods, the EDGE function
%   finds edges by thresholding the gradient.  For the Laplacian of
%   Gaussian method, EDGE thresholds the slope of the zero crossings
%   after filtering the image with a LoG filter.  For the Canny method,
%   EDGE thresholds the gradient using the derivative of a Gaussian
%   filter.
%
%   By default, the EDGE function automatically computes the threshold
%   to use. The threshold value is displayed in the text box below Threshold
%   popup menu. To specify a different threshold manually (in order to
%   detect more or fewer edges), select 'specify' in the Threshold popup menu and
%   enter the value in the text box below it.
%   If you are using the Canny method, two thresholds are used:  the
%   high threshold is the value you specify, and the low threshold is
%   0.4 times the high threshold.
%
%   For the Sobel and Prewitt methods, you can choose to detect
%   horizontal edges, vertical edges, or both from the Direction popup menu.
%
%   For the Laplacian of Gaussian and Canny methods, you can specify
%   sigma, the parameter that controls the spread of the Gaussian
%   function.  The size of the filter is set automatically by EDGE,
%   based on the value of sigma.
%
%   See also EDGE.


%   Sachin V. Patwardhan and Atam P. Dhawan
%   New Jersey Institute of Technology.

load EDGEDEMOINT

h0 = figure('Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'FileName','EDGEDEMOINT.m', ...
	'MenuBar','none', ...
	'Name','Edge Detection Interface', ...
	'NumberTitle','off', ...
	'PaperPosition',[18 180 576 432], ...
	'PaperUnits','points', ...
	'Position',[453 224 560 420], ...
	'Resize','on', ...
	'Tag','Fig1', ...
	'ToolBar','none');
h1 = uimenu('Parent',h0, ...
	'Label','image', ...
	'Tag','uimenu1');
h2 = uimenu('Parent',h1, ...
	'Callback','[image]=loadimage2;', ...
	'Label','Load', ...
	'Tag','Subuimenu1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat2, ...
	'ListboxTop',0, ...
	'Position',[9 12.75 59.25 34.5], ...
	'String',mat3, ...
	'Style','popupmenu', ...
	'Tag','edgmtd', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[9.75 52.5 59.25 15.75], ...
	'String','Method', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[77.25 51 58.5 15.75], ...
	'String','Direction', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',[75.75 10.5 59.25 34.5], ...
	'String',mat4, ...
	'Style','popupmenu', ...
	'Tag','dirval', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[144 52.5 58.5 15.75], ...
	'String','Threshold', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',[142.5 26.25 59.25 19.5], ...
	'String',mat5, ...
	'Style','popupmenu', ...
	'Tag','thrval', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',[141.75 6.75 59.25 17.25], ...
	'Style','edit', ...
	'Tag','thre');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[208.5 52.5 58.5 15.75], ...
	'String','Sigma', ...
	'Style','text', ...
	'Tag','st', ...
	'Visible','off');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',[209.25 27.75 59.25 17.25], ...
	'String','1', ...
	'Style','edit', ...
	'Tag','sigval', ...
	'Value',1, ...
	'Visible','off');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'Callback','edgeapply(image);', ...
	'ListboxTop',0, ...
	'Position',[279.75 48 57 19.5], ...
	'String','Apply', ...
	'Tag','Pushbutton1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'Callback','helpwin EDGEDEMOINT', ...
	'ListboxTop',0, ...
	'Position',[345.75 48 57 19.5], ...
	'String','Info', ...
	'Tag','Pushbutton1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'Callback','close', ...
	'ListboxTop',0, ...
	'Position',[309.75 9 57 19.5], ...
	'String','Close', ...
	'Tag','Pushbutton1');
if nargout > 0, fig = h0; end
