function fig = FIRDEMOINT()
%FIRDEMOINT Finite impulse response filter demo
%
%   This interface demonstrates the application of Finite impulse response (FIR) filters
%   To get started load the image you wish to fliter using the image menu.
%   The original image and its Fourier transform are displayed in the window.
%   The 2D FIR filter can be obtained using the following 3 methods: 
%     1. The frequency transformation method, which transforms a one-dimensional FIR filter 
%        into a two-dimensional FIR filter
%     2. The frequency sampling method, which creates a filter based on a desired frequency response
%     3. The windowing method, which multiplies the ideal impulse response with a window function to 
%        generate the filter
%   Choose the filter design method from the drop-down list under 'Method', select the filter type as 
%   high-pass or low-pass under 'Type' drop down list. If windowing method is used, select the window 
%   type under 'Window' drop down list. Enter the desired Cut-off and Filter Order values. Now press 
%   the Apply button. The filters frequency response is displayed along with the filtered image and its 
%   Fourier transform.
%     Sachin V. Patwardhan and Atam P. Dhawan
%     New Jersey Institute of Technology.

load FIRDEMOINT

h0 = figure('Units','normalized', ...
	'Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'FileName','FIRDEMOINT.m', ...
	'MenuBar','none', ...
	'Name','FIR DEMO INTERFACE', ...
	'NumberTitle','off', ...
	'PaperPosition',[18 180 576 432], ...
	'PaperUnits','points', ...
	'Position',mat1, ...
	'Tag','Fig1', ...
	'ToolBar','none');
h1 = uimenu('Parent',h0, ...
	'Label','Image', ...
	'Tag','uimenu1');
h2 = uimenu('Parent',h1, ...
	'Callback','[imagefir,Ft]=loadimage1;', ...
	'Label','Load', ...
	'Tag','Subuimenu1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Callback','firapply(imagefir,Ft);', ...
	'ListboxTop',0, ...
	'Position',[0.6982142857142857 0.1142857142857143 0.1375 0.06190476190476191], ...
	'String','Apply', ...
	'Tag','Pushbutton1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Callback','helpwin FIRDEMOINT', ...
	'ListboxTop',0, ...
	'Position',[0.8410714285714285 0.1142857142857143 0.1375 0.06190476190476191], ...
	'String','Info', ...
	'Tag','Pushbutton1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Callback','close', ...
	'ListboxTop',0, ...
	'Position',[0.7749999999999999 0.02619047619047619 0.1375 0.06190476190476191], ...
	'String','Close', ...
	'Tag','Pushbutton1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',mat2, ...
	'String','0.5', ...
	'Style','edit', ...
	'Tag','cutoff');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
    'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',mat3, ...
	'String','Cut-Off', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',mat4, ...
	'String','Order', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',mat5, ...
	'String','11', ...
	'Style','edit', ...
	'Tag','ord');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',mat6, ...
	'String','Type', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',mat7, ...
	'String',mat8, ...
	'Style','popupmenu', ...
	'Tag','filtyp', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',mat9, ...
	'String',mat10, ...
	'Style','popupmenu', ...
	'Tag','wintyp', ...
	'Value',2);
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',mat11, ...
	'String','Window', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',mat12, ...
	'String','Method', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',mat13, ...
	'String',mat14, ...
	'Style','popupmenu', ...
	'Tag','mettyp', ...
	'Value',2);
if nargout > 0, fig = h0; end

