function fig = HISTOINT()
%HISTOINT Histogram Equalization and Line Histogram demo.
% 
%   This interface enables you to explore the effects of 
%   histogram equalization, which modifies the image so 
%   that its histogram is approximately flat.  The demo displays the 
%   histograms of the original and modified images.
%   The  interface enables you to obtain a Line Histogram along the 
%   line or path specified by you.
%
%   Choose an input image using the image-Load menu in the upper 
%   left corner.  The two push buttons below (Histogram Equalization and 
%   Line Histogram) allow you to choose between histogram equalization and
%   Line Histogram.   
%
%   When you select "Histogram Equalization", the histogram of the original 
%   image is equalized and the resulting image and histogram are displayed.   
%
%   When you select "Line Histogram", you can select a line or path on the 
%   input image using the mouse by clicking on points in the image. 
%   Press <BACKSPACE> or <DELETE> to remove the previously selected point.
%   A shift-click, right-click, or double-click adds a final point and 
%   ends the selection; pressing <RETURN> finishes the selection without 
%   adding a point. Equally spaced points along the path you specify are 
%   selected, and then interpolation is used to find the intensity value for each
%   point in the path.
%
%   See also IMADJUST, IMHIST, HISTEQ, IMPROFILE.

%   Sachin V. Patwardhan and Atam P. Dhawan
%   New Jersey Institute of Technology.

load HISTOINT

h0 = figure('Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'FileName','HISTOINT.m', ...
	'MenuBar','none', ...
	'Name','Histogram Interface', ...
	'NextPlot','replace', ...
	'NumberTitle','off', ...
	'PaperPosition',[18 180 576 432], ...
	'PaperUnits','points', ...
	'Position',[432 232 560 420], ...
	'Resize','on', ...
	'Tag','Fig1', ...
	'ToolBar','none');
h1 = uimenu('Parent',h0, ...
	'Label','image', ...
	'Tag','uimenu1');
h2 = uimenu('Parent',h1, ...
	'Callback','[image]=loadimage4;', ...
	'Label','Load', ...
	'Tag','Subuimenu1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Callback','helpwin histoint', ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[0.5625 0.01714285714285714 0.1982142857142857 0.08571428571428572], ...
	'String','Info', ...
	'Tag','Pushbutton1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Callback','close', ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[0.7785714285714286 0.01714285714285715 0.1982142857142857 0.08571428571428572], ...
	'String','Close', ...
	'Tag','Pushbutton1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Callback','histline(image);', ...
	'FontSize',6, ...
	'ListboxTop',0, ...
	'Position',[0.3375 0.059 0.1982142857142857 0.042], ...
	'String','Line-Hist Main Image', ...
	'Tag','Pushbutton1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Callback','histline1(Jimage);', ...
	'FontSize',6, ...
	'ListboxTop',0, ...
	'Position',[0.3375 0.01714285714285714 0.1982142857142857 0.042], ...
	'String','Line-Hist Equa Image', ...
	'Tag','Pushbutton1');

h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Callback','[Jimage]=histapp(image);', ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[0.02142857142857142 0.01714285714285714 0.2839285714285714 0.08571428571428572], ...
	'String','Histogram Equalization', ...
	'Tag','Pushbutton1');
h1 = axes('Parent',h0, ...
	'Box','on', ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'CLimMode','manual', ...
	'Color',[1 1 1], ...
	'ColorOrder',mat1, ...
	'DataAspectRatioMode','manual', ...
	'Layer','top', ...
	'Position',[0.5779768786127169 0.7012223431265868 0.3270231213872832 0.2237776568734131], ...
	'Tag','Axes4', ...
	'TickDir','out', ...
	'TickDirMode','manual', ...
	'Visible','off', ...
	'WarpToFill','off', ...
	'WarpToFillMode','manual', ...
	'XColor',[0 0 0], ...
	'XLimMode','manual', ...
	'YColor',[0 0 0], ...
	'YLimMode','manual', ...
	'ZColor',[0 0 0]);
h2 = image('Parent',h1, ...
	'BusyAction','cancel', ...
	'CData',[], ...
	'CDataMapping','scaled', ...
	'Interruptible','off', ...
	'Tag','Axes4Image1', ...
	'XData',[1 0], ...
	'YData',[1 0]);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[0.4891304347826084 1.076086956521739 9.160254037844386], ...
	'Tag','Axes4Text4', ...
	'VerticalAlignment','bottom');
set(get(h2,'Parent'),'Title',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[0.4891304347826084 -0.2717391304347827 9.160254037844386], ...
	'Tag','Axes4Text3', ...
	'VerticalAlignment','cap', ...
	'Visible','off');
set(get(h2,'Parent'),'XLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[-0.3260869565217393 0.4891304347826087 9.160254037844386], ...
	'Rotation',90, ...
	'Tag','Axes4Text2', ...
	'VerticalAlignment','baseline', ...
	'Visible','off');
set(get(h2,'Parent'),'YLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','right', ...
	'Position',mat2, ...
	'Tag','Axes4Text1', ...
	'Visible','off');
set(get(h2,'Parent'),'ZLabel',h2);
h1 = axes('Parent',h0, ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'ColorOrder',mat3, ...
	'Position',[0.5779768786127169 0.4056111715632934 0.3270231213872832 0.2237776568734131], ...
	'Tag','Axes3', ...
	'Visible','off', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[0.4945054945054948 1.075268817204301 9.160254037844386], ...
	'Tag','Axes3Text4', ...
	'VerticalAlignment','bottom');
set(get(h2,'Parent'),'Title',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[0.4945054945054948 -0.258064516129032 9.160254037844386], ...
	'Tag','Axes3Text3', ...
	'VerticalAlignment','cap', ...
	'Visible','off');
set(get(h2,'Parent'),'XLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[-0.1593406593406592 0.4838709677419355 9.160254037844386], ...
	'Rotation',90, ...
	'Tag','Axes3Text2', ...
	'VerticalAlignment','baseline', ...
	'Visible','off');
set(get(h2,'Parent'),'YLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','right', ...
	'Position',[-1.785714285714286 2.666666666666667 9.160254037844386], ...
	'Tag','Axes3Text1', ...
	'Visible','off');
set(get(h2,'Parent'),'ZLabel',h2);
if nargout > 0, fig = h0; end
%