function fig = MORPHOPRN()
%MORPHOPRN Morphological operations demo
%
%  Morphological operations are methods for processing images based 
%  on the shape. Specified neighborhood known as the structuring element
%  is used in these operations. The state of the given pixel in the output
%  image is determined by applying a rule to the neighborhood of the 
%  corresponding pixel in the input image. The rule used defines the 
%  Morphological operation.
%
%  The main morphological operations are dilation and erosion. 
%  Dilation adds pixels to the boundaries of the objects while 
%  erosion removes pixels on the object boundaries. Most of the 
%  other Morphological operations are modified dilation or erosion,
%  or combinations of dilation and erosion.
%
%  In this interface we demonstrate some of the Morphological operations
%  on binary images preformed using the function BWMORPH. 
%  First select the image of your choice using the top menu. 
%  The image is converted to a binary image using a threshold before it is
%  displayed. Next select the operation and the number of times it is to be 
%  performed on the input image in succession. Finally click the apply push 
%  button. The output image will be displayed to the right of the input image.
%
%  See also BWMORPH, ERODE, DILATE, IM2BW. 


%   Sachin V. Patwardhan and Atam P. Dhawan
%   New Jersey Institute of Technology.

load MORPHOPRN

h0 = figure('Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'FileName','MORPHOPRN.m', ...
	'MenuBar','none', ...
	'Name','Morphological Operations', ...
	'NumberTitle','off', ...
	'PaperPosition',[18 180 576 432], ...
	'PaperUnits','points', ...
	'Position',[458 263 800 420], ...
	'Resize','on', ...
	'Tag','Fig1', ...
	'ToolBar','none');
h1 = uimenu('Parent',h0, ...
	'Label','Image', ...
	'Tag','uimenu1');
h2 = uimenu('Parent',h1, ...
	'Callback','[imagebw]=loadimage;', ...
	'Label','Load', ...
	'Tag','Imageuimenu1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Callback','close', ...
	'ListboxTop',0, ...
	'Position',mat1, ...
	'String','Close', ...
	'Tag','closebutton');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position', [17.25 17.25 77.25 23.25], ... %mat2, ...
	'String','1', ...
	'Style','edit', ...
	'Tag','norun');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Callback','close_morph(imagebw);', ...
	'ListboxTop',0, ...
	'Position',mat3, ...
	'String','Apply', ...
	'Tag','infobutton');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[17.25 47.25 77.25 23.25], ...
	'String','No of Runs', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[115.5 5.25 122.25 33.75], ...
	'String',mat4, ...
	'Style','listbox', ...
	'Tag','Opernlb', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[110.25 46.5 123 22.5], ...
	'String','Operation', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'Callback','helpwin MORPHOPRN', ...
	'ListboxTop',0, ...
	'Position',mat5, ...
	'String','Info', ...
	'Tag','closebutton');
if nargout > 0, fig = h0; end
