function fig = NOISEREDINT()
%NOISEREDINT Noise reduction filtering demo.
%
%   This interface enables you to explore noise reduction in images using
%   linear and non-linear filtering techniques applied to several 
%   kinds of noise.
%   
%   The image on the left side of the figure window is the original
%   uncorrupted image.  Use the image menu on the top to Load the image
%   of your choice.  
%
%   The center image is the original image with noise added.  Use the 
%   Noise ppopup menu below the input image to select among three different types 
%   of noise.  Edit the fields next to the Noise menu to specify parameters 
%   for the noise.  Press "Add Noise" to apply the noise.  
%   
%   The image on the right shows the result of applying a noise removal
%   filter to the center image.  Use the Filter and Neighborhood popup menus to
%   select the type of noise removal filter and the size of the 
%   neighborhood.  Press "Apply Filter" to filter the corrupted image.
%
%   See also IMNOISE, MEDFILT2, ORDFILT2, WIENER2, FILTER2.


%   Sachin V. Patwardhan and Atam P. Dhawan
%   New Jersey Institute of Technology.

load NOISEREDINT

h0 = figure('Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'FileName','NOISEREDINT.m', ...
	'MenuBar','none', ...
	'Name','Noise Reduction Filter Interface', ...
	'NumberTitle','off', ...
	'PaperPosition',[18 180 576 432], ...
	'PaperUnits','points', ...
	'Position',[474 264 560 420], ...
	'Resize','on', ...
	'Tag','Fig1', ...
	'ToolBar','none');
h1 = uimenu('Parent',h0, ...
	'Label','image', ...
	'Tag','uimenu1');
h2 = uimenu('Parent',h1, ...
	'Callback','[image]=loadimage3;', ...
	'Label','Load', ...
	'Tag','imageuimenu1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'Callback',mat1, ...
	'ListboxTop',0, ...
	'Position',[18.75 10.5 74.25 37.5], ...
	'String',mat2, ...
	'Style','popupmenu', ...
	'Tag','noisepop', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[101.25 52.5 56.25 18], ...
	'String','Density', ...
	'Style','text', ...
	'Tag','dentext', ...
	'Visible','off');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',[101.25 29.25 53.25 21], ...
	'String','0.1', ...
	'Style','edit', ...
	'Tag','denval', ...
	'Visible','off');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',[161.25 28.5 53.25 21], ...
	'String','0.0', ...
	'Style','edit', ...
	'Tag','meanval');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[160.5 52.5 56.25 18], ...
	'String','Mean', ...
	'Style','text', ...
	'Tag','meatext');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[18.75 52.5 74.25 17.5], ...
	'String','Noise Type', ...
	'Style','text', ...
	'Tag','meatext');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
	'Position',[101.25 29.25 53.25 21], ...
	'String','0.005', ...
	'Style','edit', ...
	'Tag','varval');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[101.25 52.5 56.25 18], ...
	'String','Variance', ...
	'Style','text', ...
	'Tag','vartext');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'ListboxTop',0, ...
	'Position',[220.5 24 56.25 25.5], ...
	'String',mat3, ...
	'Style','popupmenu', ...
	'Tag','filt', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[219.75 52.5 56.25 18], ...
	'String','Filter', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[279 52.5 70.5 18], ...
	'String','Neighborhood', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.43921568627451 0.43921568627451 0.43921568627451], ...
	'ListboxTop',0, ...
	'Position',[279.75 23.25 70.5 25.5], ...
	'String',mat4, ...
	'Style','popupmenu', ...
	'Tag','filtneb', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'Callback','[noiimage]=noiseadd(image);', ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[100.5 6 113.25 19.5], ...
	'String','Add Noise', ...
	'Tag','Pushbutton1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'Callback','noisefilt(noiimage);', ...
	'FontSize',10, ...
	'ListboxTop',0, ...
	'Position',[221.25 6 129 19.5], ...
	'String','Apply Filter', ...
	'Tag','Pushbutton1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'Callback','helpwin NOISEREDINT', ...
	'ListboxTop',0, ...
	'Position',[356.25 47.25 51.75 23.25], ...
	'String','Info', ...
	'Tag','Pushbutton2');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'Callback','close', ...
	'ListboxTop',0, ...
	'Position',[356.25 6 51.75 23.25], ...
	'String','Close', ...
	'Tag','Pushbutton2');
if nargout > 0, fig = h0; end
